import { create } from 'zustand'
import { devtools, persist, createJSONStorage } from 'zustand/middleware';

interface State {
  darkMode: boolean;
  collapsed: boolean;
  lang: string;
  cookie: string;
}

interface Action {
  setDarkMode: (darkMode: State['darkMode']) => void;
  setCollapsed: (collapsed: State['collapsed']) => void;
  setLang: (lang: State['lang']) => void;
  setCookie: (cookie: State['cookie']) => void;
}

export const useGlobalStore = create<State & Action>()(
  devtools(persist(
    (set) => {
      return {
        darkMode: false,
        collapsed: false,
        lang: 'zh',
        cookie: '',
        setDarkMode: (darkMode: State['darkMode']) => set({
          darkMode,
        }),
        setCollapsed: (collapsed: State['collapsed']) => set({
          collapsed,
        }),
        setLang: (lang: State['lang']) => set({
          lang,
        }),
        setCookie: (cookie: State['cookie']) => set({
          cookie,
        }),
      };
    },
    {
      name: 'globalStore',
      storage: createJSONStorage(() => localStorage),
    }
  ),
    { name: 'globalStore' }
  )
)
